@@ -37,6 +37,10 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
+#if HAVE_MOZ_BUG_956507
+#include "mozilla/Char16.h"
+#endif
+
 #include "GnomeKeyring.h"
 #include "nsMemory.h"
 #include "nsILoginInfo.h"
@@ -53,6 +57,12 @@
 #include "nsIPrefService.h"
 #include "nsIPrefBranch.h"
 
+#if HAVE_NSILMS_CHAR16_T
+typedef char16_t _char16_t;
+#else
+typedef PRUnichar _char16_t;
+#endif
+
 #pragma GCC visibility push(default)
 extern "C" {
 #include "gnome-keyring.h"
@@ -484,10 +494,10 @@ foundToLoginInfo(GnomeKeyringFound* found)
   return loginInfo;
 }
 
-PRUnichar *
+_char16_t *
 foundToHost(GnomeKeyringFound* found)
 {
-  PRUnichar *host = NULL;
+  _char16_t *host = NULL;
 
   GnomeKeyringAttribute *attrArray =
     (GnomeKeyringAttribute *)found->attributes->data;
@@ -614,8 +624,12 @@ NS_IMETHODIMP GnomeKeyring::Init()
   return ret;
 }
 
+#if HAVE_NSILMS_INITWITHFILE_2
 NS_IMETHODIMP GnomeKeyring::InitWithFile(nsIFile *aInputFile,
                                          nsIFile *aOutputFile)
+#else
+NS_IMETHODIMP GnomeKeyring::InitWithFile(nsIFile *aInputFile)
+#endif
 {
   // TODO
   return Init();
@@ -666,9 +680,13 @@ NS_IMETHODIMP GnomeKeyring::ModifyLogin(nsILoginInfo *oldLogin,
    * just remove the old login and add the new one */
   nsCOMPtr<nsILoginInfo> newLogin( do_QueryInterface(modLogin, &interfaceok) );
   if (interfaceok == NS_OK) {
-    nsresult rv = RemoveLogin(oldLogin);
-    rv |= AddLogin(newLogin);
-    return rv;
+    nsresult rvremovelogin = RemoveLogin(oldLogin);
+    nsresult rvaddlogin = AddLogin(newLogin);
+    if(NS_FAILED(rvremovelogin)) {
+        return rvremovelogin;
+    } else {
+        return rvaddlogin;
+    }
   }
 
   /* Otherwise, it has to be an nsIPropertyBag.
@@ -770,7 +788,7 @@ NS_IMETHODIMP GnomeKeyring::SearchLogins(PRUint32 *count,
 }
 
 NS_IMETHODIMP GnomeKeyring::GetAllDisabledHosts(PRUint32 *aCount,
-                                                PRUnichar ***aHostnames)
+                                                _char16_t ***aHostnames)
 {
   AutoFoundList foundList;
   GnomeKeyringResult result = findHostItemsAll(&foundList);
@@ -869,6 +887,18 @@ NS_IMETHODIMP GnomeKeyring::GetUiBusy(bool *aUiBusy)
   return NS_OK;
 }
 
+#if HAVE_NSILMS_GETISLOGGEDIN
+/**
+ * True when the master password has already been entered.
+ */
+/* readonly attribute boolean isLoggedIn; */
+NS_IMETHODIMP GnomeKeyring::GetIsLoggedIn(bool *aIsLoggedIn)
+{
+  *aIsLoggedIn = TRUE;
+  return NS_OK;
+}
+#endif
+
 
 
 /* End of implementation class template. */
